<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt </source>
        <translation>χρήση της Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Ευχαριστίες</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Βοηθήστε μας</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>είναι μια ανεξαρτήτου πλατφόρμας εφαρμογή για γρήγορη δημιουργία στιγμιοτύπων της επιφάνειας εργασίας σας.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Μία ελαφριά και ισχυρή εφαρμογή γραμμένη σε Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website</source>
        <translation>Ιστοσελίδα</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="109"/>
        <source>Licensed under the </source>
        <translation>Υπόκειται στην άδεια χρήσης </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Πνευματικά δικαιώματα &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Αν σας αρέσει η εφαρμογή μπορείτε να συμμετάσχετε στην ανάπτυξή της.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Τι μπορείτε να κάνετε;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Να μεταφράσετε το ScreenGrab σε άλλες γλώσσες</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Να κάνετε προτάσεις για τις επόμενες εκδόσεις</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Να αναφέρετε σφάλματα και δυσλειτουργίες</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Ιχνηλάτης σφαλμάτων</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="141"/>
        <source>Translate:</source>
        <translation>Μετάφραση:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Πορτογαλικά Βραζιλίας</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source> Ukrainian translation</source>
        <translation> Ουκρανική μετάφραση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="147"/>
        <source>Gennadi Motsyo</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source> Spanish translation</source>
        <translation> Ισπανική μετάφραση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="150"/>
        <source>Burjans L García D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="152"/>
        <source> Italian translation</source>
        <translation> Ιταλική μετάφραση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="156"/>
        <source>Testing:</source>
        <translation>Δοκιμές:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Υποστήριξη διπλής οθόνης και άλλων στο Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>Dual monitor support in Linux</source>
        <translation>Υποστήριξη διπλής οθόνης στο Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>κατασκευή win32 [Windows XP και 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>κατασκευή παλαιού win32 [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="162"/>
        <source>win32-build [Windows 7]</source>
        <translation>κατασκευή win32 [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="192"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Ο κατάλογος %1 δεν υπάρχει. Θέλετε να τον δημιουργήσετε;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="193"/>
        <location filename="../src/core/ui/configwidget.cpp" line="294"/>
        <source>Warning</source>
        <translation>Προειδοποίηση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="282"/>
        <source>Select directory</source>
        <translation>Επιλογή καταλόγου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="293"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Επιθυμείτε να επαναφέρετε όλες τις ρυθμίσεις στις προκαθορισμένες;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="351"/>
        <source>Example: </source>
        <translation>Παράδειγμα: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="406"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Το κλειδί αυτό χρησιμοποιείται ήδη στο ScreenGrab! Παρακαλώ επιλέξτε ένα άλλο.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="424"/>
        <source>This key is not supported on your system!</source>
        <translation>Το κλειδί αυτό δεν υποστηρίζεται από το σύστημά σας!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="444"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="58"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>είναι μια ανεξαρτήτου πλατύβαθρου εφαρμογή για γρήγορη δημιουργία στιγμιοτύπων της επιφάνειας εργασίας.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="62"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Λήψη ενός στιγμιότυπου πλήρους οθόνης</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>Take a screenshot of the active window</source>
        <translation>Λήψη ενός στιγμιότυπου του ενεργού παραθύρου</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Λήψη ενός στιγμιότυπου μιας περιοχής της οθόνης</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Run the application with a hidden main window</source>
        <translation>Εκτέλεση της εφαρμογής με το κύριο παράθυρο καταχωνιασμένο</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="431"/>
        <source>Saved</source>
        <translation>Αποθηκεύτηκε</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="431"/>
        <source>Saved to </source>
        <translation>Αποθηκεύτηκε στο </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="453"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Το όνομα του αποθηκευμένου αρχείου αντιγράφτηκε στο πρόχειρο</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="459"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Η διαδρομή του αποθηκευμένου αρχείου αντιγράφτηκε στο πρόχειρο</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="481"/>
        <source>Copied</source>
        <translation>Αντιγράφηκε</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="481"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Το στιγμιότυπο της οθόνης αντιγράφηκε στο πρόχειρο</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Τύπος στιγμιότυπου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>&amp;Νέο παράθυρο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Περιοχή της οθόνης</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Τελευταία επιλεγμένη περιοχή</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Καθυστέρηση:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Καθυστέρηση σε δευτερόλεπτα πριν από τη λήψη του στιγμιότυπου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Ουδεμία</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> δευτ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Εστίαση της περιοχής γύρω από το ποντίκι</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Χωρίς διακοσμήσεις του παραθύρου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Συμπερίληψη της κατάδειξης του ποντικιού</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Γραμμή εργαλείων</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Νέο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
        <source>Screenshot </source>
        <translation>Στιγμιότυπο </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Διπλό κλικ για άνοιγμα του στιγμιότυπου στον εξωτερικό προεπιλεγμένο προβολέα εικόνων</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
        <source>Hide</source>
        <translation>Απόκρυψη</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
        <source>Show</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
        <source>%1 Files</source>
        <translation>%1 Αρχεία</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
        <source>Save As...</source>
        <translation>Αποθήκευση ως...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="170"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Κλικ και σύρσιμο για σχεδίαση ενός ορθογωνίου
δεξί κλικ για ταίριασμα στις άκρες
διπλό κλικ ή Enter για
λήψη του στιγμιότυπου.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="202"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 εικονοστοιχεία </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Εξωτερική επεξεργασία</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Επεξεργασία με...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="128"/>
        <source>About Qt</source>
        <translation>Σχετικά με την Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="154"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="628"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Κύριο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Για προχωρημένους</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Πλαίσιο συστήματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Συντομεύσεις</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Προεπιλεγμένος κατάλογος αποθήκευσης</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Περιήγηση του συστήματος αρχείων</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Περιήγηση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Προκαθορισμένο αρχείο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Προκαθορισμένο όνομα αρχείου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Μορφή</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Προκαθορισμένη μορφή αποθήκευσης της εικόνας</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Αντιγραφή του ονόματος αρχείου στο πρόχειρο κατά την αποθήκευση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Να μην αντιγραφεί</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Αντιγραφή μόνο του ονόματος του αρχείου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Αντιγραφή της πλήρους διαδρομής</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Ποιότητα εικόνας</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Ποιότητα εικόνας (1 - μικρό αρχείο, 100 - υψηλή ποιότητα)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Εισαγωγή της τρέχουσας ώρας και ημερομηνίας στο όνομα αρχείου αποθήκευσης</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Εισαγωγή της τρέχουσας ώρας και ημερομηνίας στο όνομα αρχείου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Πρότυπο: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Παράδειγμα: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Αυτόματη αποθήκευση των στιγμιότυπων κατά την διαδικασία σύλληψης</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Αυτόματη αποθήκευση του στιγμιότυπου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Αποθήκευση του πρώτου στιγμιότυπου</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Να επιτρέπονται περισσότερες εκτελέσεις του Screengrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Να επιτρέπονται περισσότερες εκτελέσεις του Screengrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Άνοιγμα σε εξωτερικό προβολέα με διπλό κλικ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Ενεργοποίηση του εξωτερικού προβολέα</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Αν είναι αποεπιλεγμένο, η επιλεγμένη περιοχή μπορεί
να αυξηθεί για να ταιριάξει στο εξωτερικό περιθώριο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Ταίριασμα στις άκρες εντός της επιλεγμένης περιοχής με διπλό κλικ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="449"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Εμφάνιση του ScreenGrab στο πλαίσιο συστήματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="458"/>
        <source>Tray messages:</source>
        <translation>Μηνύματα πλαισίου συστήματος:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="471"/>
        <source>Tray messages display mode</source>
        <translation>Τρόπος εμφάνισης των μηνυμάτων του πλαισίου συστήματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="475"/>
        <source>Never</source>
        <translation>Ποτέ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="480"/>
        <source>Tray mode</source>
        <translation>Λειτουργία πλαισίου συστήματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="485"/>
        <source>Always</source>
        <translation>Πάντα</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="497"/>
        <source>Time of display tray messages</source>
        <translation>Χρόνος εμφάνισης των μηνυμάτων του πλαισίου συστήματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="513"/>
        <source>Time to display tray messages</source>
        <translation>Χρόνος για την εμφάνιση των μηνυμάτων του πλαισίου συστήματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source> sec</source>
        <translation> δευτ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="534"/>
        <source>Minimize to tray on click close button</source>
        <translation>Ελαχιστοποίηση στο πλαίσιο συστήματος με κλικ στο κουμπί κλεισίματος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="537"/>
        <source>Minimize to tray when closing</source>
        <translation>Ελαχιστοποίηση στο πλαίσιο συστήματος κατά το κλείσιμο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="576"/>
        <source>Action</source>
        <translation>Ενέργεια</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="581"/>
        <source>Shortcut</source>
        <translation>Συντόμευση</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="586"/>
        <source>Global shortcuts</source>
        <translation>Καθολικές συντομεύσεις</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="593"/>
        <source>Full screen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="598"/>
        <source>Active window</source>
        <translation>Ενεργό παράθυρο</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="603"/>
        <source>Area select</source>
        <translation>Επιλογή περιοχής</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="609"/>
        <source>Local shortcuts</source>
        <translation>Τοπικές συντομεύσεις</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="613"/>
        <source>New screen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="618"/>
        <source>Save screen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="623"/>
        <source>Copy screen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="633"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="638"/>
        <source>Quit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="649"/>
        <source>Selected shortcut:</source>
        <translation>Επιλεγμένη συντόμευση:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="656"/>
        <source>Not defined</source>
        <translation>Δεν προσδιορίστηκε</translation>
    </message>
</context>
</TS>
